@@ -1,7 +1,7 @@
 package App::CSVUtils;
 
 our $DATE = '2019-04-23'; # DATE
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 use 5.010001;
 use strict;
@@ -264,10 +264,11 @@ $SPEC{csvutil} = {
         %args_common,
         action => {
             schema => ['str*', in=>[
-                'list-field-names',
-                'munge-field',
-                'delete-field',
                 'add-field',
+                'list-field-names',
+                'delete-field',
+                'munge-field',
+                'replace-newline',
                 'sort-fields',
                 'sum',
                 'avg',
@@ -276,7 +277,9 @@ $SPEC{csvutil} = {
                 'map',
                 'each-row',
                 'convert-to-hash',
+                'concat',
                 'select-fields',
+                'dump',
             ]],
             req => 1,
             pos => 0,
@@ -1150,7 +1153,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 0.016 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-04-23.
+This document describes version 0.017 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-04-23.
 
 =head1 DESCRIPTION
 
